// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
//
// See the LICENSE.txt file for license information. Please report all
// bugs and problems to the public mailing list <gmsh@onelab.info>.
//
// Contributor(s):
//   Eric Bechet
//

#ifndef _MATERIALLAW_H_
#define _MATERIALLAW_H_

class Material {
public:
  virtual ~Material() {}
};

#endif //_MATERIALLAW_H_
